/*
 *
 *  This file is part of MUMPS 5.1.1, released
 *  on Mon Mar 20 14:34:33 UTC 2017
 *
 *
 *  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
 *  University of Bordeaux.
 *
 *  This version of MUMPS is provided to you free of charge. It is
 *  released under the CeCILL-C license:
 *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
 *
 */
#ifndef MUMPS_SAVE_RESTORE_C_H
#define MUMPS_SAVE_RESTORE_C_H
#include "mumps_common.h"
#define MUMPS_SAVE_RESTORE_RETURN_C \
    F_SYMBOL(save_restore_return_c,SAVE_RESTORE_RETURN_C)
void MUMPS_CALL
MUMPS_SAVE_RESTORE_RETURN_C();
#endif /* MUMPS_SAVE_RESTORE_C_H */
